@@ -52,14 +52,14 @@ class OTAUpdater:
         batFile = (
             """@echo off
 color a
-echo [+] pkscreener Software Updater!
-echo [+] Downloading Software Update...
-echo [+] This may take some time as per your Internet Speed, Please Wait...
+echo   [+] pkscreener Software Updater!
+echo   [+] Downloading Software Update...
+echo   [+] This may take some time as per your Internet Speed, Please Wait...
 curl -o pkscreenercli.exe -L """
             + url
             + """
-echo [+] Newly downloaded file saved in %cd%
-echo [+] Software Update Completed! Run'pkscreenercli.exe' again as usual to continue..
+echo   [+] Newly downloaded file saved in %cd%
+echo   [+] Software Update Completed! Run'pkscreenercli.exe' again as usual to continue..
 pause
 del updater.bat & exit
         """
@@ -74,20 +74,28 @@ del updater.bat & exit
     def updateForLinux(url):
         if url is None or len(url) == 0:
             return
+        from PKDevTools.classes.System import PKSystem
+        _,_,_,_,sysArch = PKSystem.get_platform()
         bashFile = (
             """#!/bin/bash
 echo ""
-echo "[+] Starting PKScreener updater, Please Wait..."
+echo "  [+] Starting PKScreener updater, Please Wait..."
 sleep 3
-echo "[+] pkscreener Software Updater!"
-echo "[+] Downloading Software Update..."
-echo "[+] This may take some time as per your Internet Speed, Please Wait..."
+echo "  [+] pkscreener Software Updater!"
+echo "  [+] Downloading Software Update..."
+echo "  [+] This may take some time as per your Internet Speed, Please Wait..."
 wget -q """
             + url
-            + """ -O pkscreenercli.bin
-echo "[+] Newly downloaded file saved in $(pwd)"
-chmod +x pkscreenercli.bin
-echo "[+] Update Completed! Run 'pkscreenercli.bin' again as usual to continue.."
+            + """ -O pkscreenercli_"""
+            + sysArch
+            + """.bin
+echo "  [+] Newly downloaded file saved in $(pwd)"
+chmod +x pkscreenercli_"""
+            + sysArch
+            + """.bin
+echo "  [+] Update Completed! Run 'pkscreenercli_"""
+            + sysArch 
+            + """.bin' again as usual to continue.."
 rm updater.sh
         """
         )
@@ -102,20 +110,28 @@ rm updater.sh
     def updateForMac(url):
         if url is None or len(url) == 0:
             return
+        from PKDevTools.classes.System import PKSystem
+        _,_,_,_,sysArch = PKSystem.get_platform()
         bashFile = (
             """#!/bin/bash
 echo ""
-echo "[+] Starting PKScreener updater, Please Wait..."
+echo "  [+] Starting PKScreener updater, Please Wait..."
 sleep 3
-echo "[+] pkscreener Software Updater!"
-echo "[+] Downloading Software Update..."
-echo "[+] This may take some time as per your Internet Speed, Please Wait..."
-curl -o pkscreenercli.run -L """
+echo "  [+] pkscreener Software Updater!"
+echo "  [+] Downloading Software Update..."
+echo "  [+] This may take some time as per your Internet Speed, Please Wait..."
+curl -o pkscreenercli_"""
+            + sysArch
+            + """.run -L """
             + url
             + """
-echo "[+] Newly downloaded file saved in $(pwd)"
-chmod +x pkscreenercli.run
-echo "[+] Update Completed! Run 'pkscreenercli.run' again as usual to continue.."
+echo "  [+] Newly downloaded file saved in $(pwd)"
+chmod +x pkscreenercli_"""
+            + sysArch
+            + """.run
+echo "  [+] Update Completed! Run 'pkscreenercli_"""
+            + sysArch
+            + """.run' again as usual to continue.."
 rm updater.sh
         """
         )
@@ -139,13 +155,15 @@ rm updater.sh
         resp = OTAUpdater.fetcher.fetchURL(
             "https://api.github.com/repos/pkjmesra/PKScreener/releases/latest"
         )  
-
+        size = 0
+        from PKDevTools.classes.System import PKSystem
+        _,_,_,_,sysArch = PKSystem.get_platform()
         if "Windows" in platform.system():
             exe_name = "pkscreenercli.exe"
         elif "Darwin" in platform.system():
-            exe_name = "pkscreenercli.run"
+            exe_name = f"pkscreenercli_{sysArch}.run"
         else:
-            exe_name = "pkscreenercli.bin"
+            exe_name = f"pkscreenercli_{sysArch}.bin"
         for asset in resp.json()["assets"]:
             url = asset["browser_download_url"]
             if url.endswith(exe_name):
@@ -192,16 +210,14 @@ rm updater.sh
             if prod_update:
                 if skipDownload:
                     OutputControls().printOutput(
-                        colorText.BOLD
-                        + colorText.GREEN
-                        + f"    [+] A {updateType} software update (v{tag} [{size} MB]) is available. Check out with the menu option U."
+                        colorText.GREEN
+                        + f"      [+] A {updateType} software update (v{tag} [{size} MB]) is available. Check out with the menu option U."
                         + colorText.END
                     )
                     return
                 OutputControls().printOutput(
-                    colorText.BOLD
-                    + colorText.WARN
-                    + "[+] What's New in this Update?\n"
+                    colorText.WARN
+                    + "  [+] What's New in this Update?\n"
                     + colorText.END
                     + colorText.GREEN
                     + OTAUpdater.showWhatsNew()
@@ -209,21 +225,20 @@ rm updater.sh
                 )
                 try:
                     action = input(
-                            colorText.BOLD
-                            + colorText.FAIL
+                            colorText.FAIL
                             + (
-                                f"\n[+] New {updateType} Software update (v%s) available. Download Now (Size: %dMB)? [Y/N]: "
+                                f"\n  [+] New {updateType} Software update (v%s) available. Download Now (Size: %dMB)? [Y/N]: "
                                 % (str(tag), size)
                             )
                         ) or "y"
-                except EOFError: # user pressed enter
+                except (EOFError, OSError): # user pressed enter
                     action = "y"
                     pass
                 if action is not None and action.lower() == "y":
                     if inContainer:
                         OutputControls().printOutput(
                                 colorText.WARN
-                                + f"[+] You are running in docker. Please use\n[+]{colorText.END} {colorText.GREEN}docker pull pkjmesra/pkscreener:latest{colorText.END} {colorText.WARN}to pull the latest image, followed by\n[+]{colorText.END} {colorText.GREEN}docker run -it pkjmesra/pkscreener:latest{colorText.END} {colorText.WARN}to run in the container.{colorText.END}"
+                                + f"  [+] You are running in docker. Please use\n  [+]{colorText.END} {colorText.GREEN}docker pull pkjmesra/pkscreener:latest{colorText.END} {colorText.WARN}to pull the latest image, followed by\n  [+]{colorText.END} {colorText.GREEN}docker run -it pkjmesra/pkscreener:latest{colorText.END} {colorText.WARN}to run in the container.{colorText.END}"
                             )
                         from time import sleep
                         sleep(5)
@@ -236,22 +251,22 @@ rm updater.sh
                                 OTAUpdater.updateForMac(OTAUpdater.checkForUpdate.url)
                             else:
                                 OTAUpdater.updateForLinux(OTAUpdater.checkForUpdate.url)
+                        except KeyboardInterrupt: # pragma: no cover
+                            raise KeyboardInterrupt
                         except Exception as e:  # pragma: no cover
                             default_logger().debug(e, exc_info=True)
                             OutputControls().printOutput(
-                                colorText.BOLD
-                                + colorText.WARN
-                                + "[+] Error occured while updating!"
+                                colorText.WARN
+                                + "  [+] Error occured while updating!"
                                 + colorText.END
                             )
                             raise (e)
             elif not prod_update and not skipDownload:
                 if tag.lower() == VERSION.lower():
                     OutputControls().printOutput(
-                        colorText.BOLD
-                        + colorText.GREEN
+                        colorText.GREEN
                         + (
-                            "[+] No new update available. You have the latest version (v%s) !"
+                            "  [+] No new update available. You have the latest version (v%s) !"
                             % VERSION
                         )
                         + colorText.END
@@ -262,52 +277,49 @@ rm updater.sh
                         float(now_components[2]) > float(version_components[2]) or \
                         float(now_components[3]) > float(version_components[3]):
                         OutputControls().printOutput(
-                            colorText.BOLD
-                            + colorText.FAIL
-                            + (f"[+] This version (v{VERSION}) is in Development! Thanks for trying out!")
+                            colorText.FAIL
+                            + (f"  [+] This version (v{VERSION}) is in Development! Thanks for trying out!")
                             + colorText.END
                         )
                         return OTAUpdater.developmentVersion
                     else:
                         OutputControls().printOutput(
-                        colorText.BOLD
-                        + colorText.GREEN
+                        colorText.GREEN
                         + (
-                            "[+] No new update available. You have the latest version (v%s) !"
+                            "  [+] No new update available. You have the latest version (v%s) !"
                             % VERSION
                         )
                         + colorText.END
                     )
+        except KeyboardInterrupt: # pragma: no cover
+            raise KeyboardInterrupt
         except Exception as e:  # pragma: no cover
             default_logger().debug(e, exc_info=True)
             if OTAUpdater.checkForUpdate.url is not None:
                 OutputControls().printOutput(e)
                 OutputControls().printOutput(
-                    colorText.BOLD
-                    + colorText.BLUE
+                    colorText.BLUE
                     + (
-                        "[+] Download update manually from %s\n"
+                        "  [+] Download update manually from %s\n"
                         % OTAUpdater.checkForUpdate.url
                     )
                     + colorText.END
                 )
             else:
                 OTAUpdater.checkForUpdate.url = (
-                    "[+] No exe/bin/run file as an update available!"
+                    "  [+] No exe/bin/run file as an update available!"
                 )
             if resp is not None and resp.json()["message"] == "Not Found":
                 OutputControls().printOutput(
-                    colorText.BOLD
-                    + colorText.FAIL
+                    colorText.FAIL
                     + OTAUpdater.checkForUpdate.url
                     + colorText.END
                 )
             if not skipDownload:
                 OutputControls().printOutput(e)
                 OutputControls().printOutput(
-                    colorText.BOLD
-                    + colorText.FAIL
-                    + "[+] Failure while checking update!"
-                    + colorText.END
+                    colorText.FAIL
+                    + "  [+] Failure while checking update!"
+                    + colorText.END,
                 )
         return
